/******************************************************************************
* PIC USB
* interrupt.c
******************************************************************************/

/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"
#include "system\interrupt\interrupt.h"

/** V A R I A B L E S ********************************************************/
extern BOOL I2C_xfer_done;
extern unsigned char I2C_temp[3];
extern unsigned char I2C_result[3];
extern unsigned char I2C_counter;

/** P R I V A T E  P R O T O T Y P E S ***************************************/
void high_isr(void);
void low_isr(void);

/** I N T E R R U P T  V E C T O R S *****************************************/

#pragma code high_vector=0x08
void interrupt_at_high_vector(void)
{
    _asm goto high_isr _endasm
}
#pragma code

#pragma code low_vector=0x18
void interrupt_at_low_vector(void)
{
    _asm goto low_isr _endasm
}
#pragma code

/** D E C L A R A T I O N S **************************************************/
/******************************************************************************
 * Function:        void high_isr(void)
 * PreCondition:    None
 * Input:
 * Output:
 * Side Effects:
 * Overview:
 *****************************************************************************/
#pragma interrupt high_isr
void high_isr(void)
{
  unsigned char dummy;

  INTCONbits.RBIF = 0;
  if(PIR1bits.SSPIF)	
  {
	if (SSPCON1bits.SSPOV)						//Throw away result if overflow and flush error
	{
	  dummy = SSPBUF;
	  SSPCON1bits.SSPOV = 0;
	}
	else if (SSPSTATbits.BF)					//Only interested if buffer has something in it
	{
	  if (!SSPSTATbits.D_A)						//If address byte, throw it away and get ready for data
	  {
		dummy = SSPBUF;
	  	I2C_counter = 2;
	  }
	  else if (I2C_counter!=0xFF)				//If data, take only first three bytes
	  {
		I2C_temp[I2C_counter--] = SSPBUF;
		if (I2C_counter == 0xFF)
		{
		  I2C_result[2] = I2C_temp[2];
		  I2C_result[1] = I2C_temp[1];
		  I2C_result[0] = I2C_temp[0];
		  I2C_xfer_done = TRUE;
		}
		else
		  dummy = SSPBUF;
	  }
	}
  	PIR1bits.SSPIF = 0;							//Clear interrupt flag
  }
}

/******************************************************************************
 * Function:        void low_isr(void)
 * PreCondition:    None
 * Input:
 * Output:
 * Side Effects:
 * Overview:
 *****************************************************************************/
#pragma interruptlow low_isr
void low_isr(void)
{
}
#pragma code

/** EOF interrupt.c **********************************************************/
